@@ -9,13 +9,21 @@
 	
 	if (length(x) < 1) { stop('no Rasters') }
 	compare(x)
+	
+	nl <- sapply(x, nlayers)
+	un <- unique(nl)
+	#if ( max( max(un) %% un ) > 0) {
+	#	stop('number of layers does not match (and cannot be recycled): ', paste(un, collapse=', '))
+	#} 
 
 	filename <- trim(filename)
 	nl <- sapply(x, nlayers)
-	if (nl[1] == 1) {
+	maxnl <- max(nl)
+	if (maxnl == 1) {
 		outraster <- raster(x[[1]])
 	} else {
 		outraster <- brick(x[[1]], values=FALSE)
+		outraster@data@nlayers <- as.integer(maxnl)
 	}
 
 	testmat <- matrix(1:10, nrow=10, ncol=length(x)) 
@@ -45,28 +53,33 @@
 		pb <- pbCreate(3, type=.progress(...))			
 		pbStep(pb, 1)
 		if (doapply) {
-			valmat = matrix(nrow=ncell(outraster)*nlayers(outraster) , ncol=length(x)) 
+			valmat = matrix(nrow= ncell(outraster)*maxnl , ncol=length(x)) 
 			for (i in 1:length(x)) {
-				valmat[,i] <- as.vector(getValues(x[[i]]))
-			}	
+				if (ncell(x[[i]] < nrow(valmat))) {
+					valmat[,i] <- as.vector(getValues(x[[i]])) * rep(1, nrow(valmat))
+				} else {
+					valmat[,i] <- as.vector(getValues(x[[i]]))
+				}
+			}
 			pbStep(pb, 2)
 
 			vals <- apply(valmat, 1, fun)
 			if (! is.null(dim(vals))) {
 				vals <- t(vals)
 			}
-			if (nlayers(outraster) > 1) {
-				vals <- matrix(vals, ncol=nlayers(outraster))
+			if (maxnl > 1) {
+				vals <- matrix(vals, ncol=maxnl)
 			}
 			
 		} else {
-			vallist <- list()
 			for (i in 1:length(x)) {
-				vallist[[i]] <- getValues(x[[i]])
-				x[[i]] <- clearValues(x[[i]])
+				x[[i]] <- as.vector(getValues(x[[i]]))
 			}
 			pbStep(pb, 2)
-			vals <- do.call(fun, vallist)
+			vals <- do.call(fun, x)
+			if (maxnl > 1) {
+				vals <- matrix(vals, ncol=maxnl)
+			}
 		}
 		
 		outraster <- setValues(outraster, vals)
@@ -75,6 +88,7 @@
 		}
 		pbStep(pb, 3)
 		pbClose(pb)
+		return(outraster)
 		
 	} else {
 	
@@ -93,8 +107,13 @@
 					valmat = matrix(nrow=tr$nrows[i]*ncol(outraster)*nlayers(outraster) , ncol=length(x))
 				}
 				for (j in 1:length(x)) {
-					valmat[,j] <- as.vector(getValues(x[[j]], row=tr$row[i], nrows=tr$size))
+					if (ncell(x[[i]] < nrow(valmat))) {
+						valmat[,j] <- as.vector(getValues(x[[j]], row=tr$row[i], nrows=tr$size)) * rep(1, nrow(valmat))
+					} else {
+						valmat[,j] <- as.vector(getValues(x[[j]], row=tr$row[i], nrows=tr$size))
+					}
 				}	
+				
 				vv <- apply(valmat, 1, fun)
 				if (! is.null(dim(vv))) {
 					vals <- t(vv)
@@ -110,9 +129,12 @@
 			vallist <- list()
 			for (i in 1:tr$n) {
 				for (j in 1:length(x)) {
-					vallist[[j]] <- getValues(x[[j]], row=tr$row[i], nrows=tr$size)
+					vallist[[j]] <- as.vector( getValues(x[[j]], row=tr$row[i], nrows=tr$size) )
 				}	
 				vv <- do.call(fun, vallist)
+				if (maxnl > 1) {
+					vv <- matrix(vv, ncol=maxnl)
+				}
 				outraster <- writeValues(outraster, vv, tr$row[i])
 				pbStep(pb, i)
 			}
