@@ -1,5 +1,4 @@
 # Author: Robert J. Hijmans, r.hijmans@gmail.com
-# International Rice Research Institute
 # Date : March 2009
 # Version 0.9
 # Licence GPL v3
@@ -20,9 +19,18 @@ setMethod("unstack", signature(x='RasterBrick'),
 function(x) {
 	rlist <- list()
 	if (nlayers(x) == 0) { return(rlist) }
+	r <- raster(x, 1)
 	for (i in 1:nlayers(x)) {
-		rlist <- c(rlist, raster(x, i))
+		r@data@band <- i
+		rlist <- c(rlist, r)
 	}
+
+	if (! fromDisk(x) ) { 
+		for (i in 1:nlayers(x)) {
+			rlist[i] <- setValues(rlist[[i]], x@data@values[,i])
+		}
+	}
+	
 	return(rlist)
 } )
 
